# Generated by Django 2.2.14 on 2020-10-07 03:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_advanced_form_builder', '0006_auto_20201007_1626'),
    ]

    operations = [
        migrations.AddField(
            model_name='abstractadvancedemailform',
            name='use_browser_validation',
            field=models.BooleanField(blank=True, default=False, help_text='Tick this to use the in-built browser validation on fields'),
        ),
        migrations.AddField(
            model_name='abstractadvancedform',
            name='use_browser_validation',
            field=models.BooleanField(blank=True, default=False, help_text='Tick this to use the in-built browser validation on fields'),
        ),
    ]
